package org.jeecg.modules.cityAddr.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.cityAddr.entity.CityAddr;
import org.jeecg.modules.cityAddr.service.ICityAddrService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 服务区域
 * @Author: jeecg-boot
 * @Date:   2024-10-14
 * @Version: V1.0
 */
@Api(tags="服务区域")
@RestController
@RequestMapping("/cityAddr/cityAddr")
@Slf4j
public class CityAddrController extends JeecgController<CityAddr, ICityAddrService>{
	@Autowired
	private ICityAddrService cityAddrService;
	
	/**
	 * 分页列表查询
	 *
	 * @param cityAddr
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "服务区域-分页列表查询")
	@ApiOperation(value="服务区域-分页列表查询", notes="服务区域-分页列表查询")
	@GetMapping(value = "/rootList")
	public Result<IPage<CityAddr>> queryPageList(CityAddr cityAddr,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		String hasQuery = req.getParameter("hasQuery");
        if(hasQuery != null && "true".equals(hasQuery)){
            QueryWrapper<CityAddr> queryWrapper =  QueryGenerator.initQueryWrapper(cityAddr, req.getParameterMap());
            List<CityAddr> list = cityAddrService.queryTreeListNoPage(queryWrapper);
            IPage<CityAddr> pageList = new Page<>(1, 10, list.size());
            pageList.setRecords(list);
            return Result.OK(pageList);
        }else{
            String parentId = cityAddr.getPid();
            if (oConvertUtils.isEmpty(parentId)) {
                parentId = "0";
            }
            cityAddr.setPid(null);
            QueryWrapper<CityAddr> queryWrapper = QueryGenerator.initQueryWrapper(cityAddr, req.getParameterMap());
            // 使用 eq 防止模糊查询
            queryWrapper.eq("pid", parentId);
            Page<CityAddr> page = new Page<CityAddr>(pageNo, pageSize);
            IPage<CityAddr> pageList = cityAddrService.page(page, queryWrapper);
            return Result.OK(pageList);
        }
	}

	 /**
      * 获取子数据
      * @param cityAddr
      * @param req
      * @return
      */
	//@AutoLog(value = "服务区域-获取子数据")
	@ApiOperation(value="服务区域-获取子数据", notes="服务区域-获取子数据")
	@GetMapping(value = "/childList")
	public Result<IPage<CityAddr>> queryPageList(CityAddr cityAddr,HttpServletRequest req) {
		QueryWrapper<CityAddr> queryWrapper = QueryGenerator.initQueryWrapper(cityAddr, req.getParameterMap());
		List<CityAddr> list = cityAddrService.list(queryWrapper);
		IPage<CityAddr> pageList = new Page<>(1, 10, list.size());
        pageList.setRecords(list);
		return Result.OK(pageList);
	}

    /**
      * 批量查询子节点
      * @param parentIds 父ID（多个采用半角逗号分割）
      * @return 返回 IPage
      * @param parentIds
      * @return
      */
	//@AutoLog(value = "服务区域-批量获取子数据")
    @ApiOperation(value="服务区域-批量获取子数据", notes="服务区域-批量获取子数据")
    @GetMapping("/getChildListBatch")
    public Result getChildListBatch(@RequestParam("parentIds") String parentIds) {
        try {
            QueryWrapper<CityAddr> queryWrapper = new QueryWrapper<>();
            List<String> parentIdList = Arrays.asList(parentIds.split(","));
            queryWrapper.in("pid", parentIdList);
            List<CityAddr> list = cityAddrService.list(queryWrapper);
            IPage<CityAddr> pageList = new Page<>(1, 10, list.size());
            pageList.setRecords(list);
            return Result.OK(pageList);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            return Result.error("批量查询子节点失败：" + e.getMessage());
        }
    }
	
	/**
	 *   添加
	 *
	 * @param cityAddr
	 * @return
	 */
	@AutoLog(value = "服务区域-添加")
	@ApiOperation(value="服务区域-添加", notes="服务区域-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody CityAddr cityAddr) {
		cityAddrService.addCityAddr(cityAddr);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param cityAddr
	 * @return
	 */
	@AutoLog(value = "服务区域-编辑")
	@ApiOperation(value="服务区域-编辑", notes="服务区域-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody CityAddr cityAddr) {
		cityAddrService.updateCityAddr(cityAddr);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "服务区域-通过id删除")
	@ApiOperation(value="服务区域-通过id删除", notes="服务区域-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		cityAddrService.deleteCityAddr(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "服务区域-批量删除")
	@ApiOperation(value="服务区域-批量删除", notes="服务区域-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.cityAddrService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功！");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "服务区域-通过id查询")
	@ApiOperation(value="服务区域-通过id查询", notes="服务区域-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<CityAddr> queryById(@RequestParam(name="id",required=true) String id) {
		CityAddr cityAddr = cityAddrService.getById(id);
		if(cityAddr==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(cityAddr);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param cityAddr
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, CityAddr cityAddr) {
		return super.exportXls(request, cityAddr, CityAddr.class, "服务区域");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
		return super.importExcel(request, response, CityAddr.class);
    }

}
