package org.jeecg.modules.owParam.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.owParam.entity.OwParam;
import org.jeecg.modules.owParam.service.IOwParamService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: ow_param
 * @Author: jeecg-boot
 * @Date:   2024-10-11
 * @Version: V1.0
 */
@Api(tags="ow_param")
@RestController
@RequestMapping("/owParam/owParam")
@Slf4j
public class OwParamController extends JeecgController<OwParam, IOwParamService> {
	@Autowired
	private IOwParamService owParamService;
	
	/**
	 * 分页列表查询
	 *
	 * @param owParam
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "ow_param-分页列表查询")
	@ApiOperation(value="ow_param-分页列表查询", notes="ow_param-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<OwParam>> queryPageList(OwParam owParam,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<OwParam> queryWrapper = QueryGenerator.initQueryWrapper(owParam, req.getParameterMap());
		Page<OwParam> page = new Page<OwParam>(pageNo, pageSize);
		IPage<OwParam> pageList = owParamService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param owParam
	 * @return
	 */
	@AutoLog(value = "ow_param-添加")
	@ApiOperation(value="ow_param-添加", notes="ow_param-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody OwParam owParam) {
		owParamService.save(owParam);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param owParam
	 * @return
	 */
	@AutoLog(value = "ow_param-编辑")
	@ApiOperation(value="ow_param-编辑", notes="ow_param-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody OwParam owParam) {
		owParamService.updateById(owParam);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "ow_param-通过id删除")
	@ApiOperation(value="ow_param-通过id删除", notes="ow_param-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		owParamService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "ow_param-批量删除")
	@ApiOperation(value="ow_param-批量删除", notes="ow_param-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.owParamService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "ow_param-通过id查询")
	@ApiOperation(value="ow_param-通过id查询", notes="ow_param-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<OwParam> queryById(@RequestParam(name="id",required=true) String id) {
		OwParam owParam = owParamService.getById(id);
		if(owParam==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(owParam);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param owParam
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, OwParam owParam) {
        return super.exportXls(request, owParam, OwParam.class, "ow_param");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, OwParam.class);
    }

}
