package org.jeecg.modules.owProduct.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.owProduct.entity.OwProduct;
import org.jeecg.modules.owProduct.service.IOwProductService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: ow_product
 * @Author: jeecg-boot
 * @Date:   2024-10-11
 * @Version: V1.0
 */
@Api(tags="ow_product")
@RestController
@RequestMapping("/owProduct/owProduct")
@Slf4j
public class OwProductController extends JeecgController<OwProduct, IOwProductService> {
	@Autowired
	private IOwProductService owProductService;
	
	/**
	 * 分页列表查询
	 *
	 * @param owProduct
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "ow_product-分页列表查询")
	@ApiOperation(value="ow_product-分页列表查询", notes="ow_product-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<OwProduct>> queryPageList(OwProduct owProduct,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<OwProduct> queryWrapper = QueryGenerator.initQueryWrapper(owProduct, req.getParameterMap());
		Page<OwProduct> page = new Page<OwProduct>(pageNo, pageSize);
		IPage<OwProduct> pageList = owProductService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param owProduct
	 * @return
	 */
	@AutoLog(value = "ow_product-添加")
	@ApiOperation(value="ow_product-添加", notes="ow_product-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody OwProduct owProduct) {
		owProductService.save(owProduct);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param owProduct
	 * @return
	 */
	@AutoLog(value = "ow_product-编辑")
	@ApiOperation(value="ow_product-编辑", notes="ow_product-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody OwProduct owProduct) {
		owProductService.updateById(owProduct);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "ow_product-通过id删除")
	@ApiOperation(value="ow_product-通过id删除", notes="ow_product-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		owProductService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "ow_product-批量删除")
	@ApiOperation(value="ow_product-批量删除", notes="ow_product-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.owProductService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "ow_product-通过id查询")
	@ApiOperation(value="ow_product-通过id查询", notes="ow_product-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<OwProduct> queryById(@RequestParam(name="id",required=true) String id) {
		OwProduct owProduct = owProductService.getById(id);
		if(owProduct==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(owProduct);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param owProduct
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, OwProduct owProduct) {
        return super.exportXls(request, owProduct, OwProduct.class, "ow_product");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, OwProduct.class);
    }

}
