package org.jeecg.modules.userRole.controller;

import java.util.Arrays;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.userRole.entity.TbUserRole;
import org.jeecg.modules.userRole.service.ITbUserRoleService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 角色表
 * @Author: jeecg-boot
 * @Date:   2024-10-16
 * @Version: V1.0
 */
@Api(tags="角色表")
@RestController
@RequestMapping("/userRole/tbUserRole")
@Slf4j
public class TbUserRoleController extends JeecgController<TbUserRole, ITbUserRoleService> {
	@Autowired
	private ITbUserRoleService tbUserRoleService;
	
	/**
	 * 分页列表查询
	 *
	 * @param tbUserRole
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "角色表-分页列表查询")
	@ApiOperation(value="角色表-分页列表查询", notes="角色表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<TbUserRole>> queryPageList(TbUserRole tbUserRole,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<TbUserRole> queryWrapper = QueryGenerator.initQueryWrapper(tbUserRole, req.getParameterMap());
		Page<TbUserRole> page = new Page<TbUserRole>(pageNo, pageSize);
		IPage<TbUserRole> pageList = tbUserRoleService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param tbUserRole
	 * @return
	 */
	@AutoLog(value = "角色表-添加")
	@ApiOperation(value="角色表-添加", notes="角色表-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody TbUserRole tbUserRole) {
		tbUserRoleService.save(tbUserRole);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param tbUserRole
	 * @return
	 */
	@AutoLog(value = "角色表-编辑")
	@ApiOperation(value="角色表-编辑", notes="角色表-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody TbUserRole tbUserRole) {
		tbUserRoleService.updateById(tbUserRole);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "角色表-通过id删除")
	@ApiOperation(value="角色表-通过id删除", notes="角色表-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		tbUserRoleService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "角色表-批量删除")
	@ApiOperation(value="角色表-批量删除", notes="角色表-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.tbUserRoleService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "角色表-通过id查询")
	@ApiOperation(value="角色表-通过id查询", notes="角色表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<TbUserRole> queryById(@RequestParam(name="id",required=true) String id) {
		TbUserRole tbUserRole = tbUserRoleService.getById(id);
		if(tbUserRole==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(tbUserRole);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param tbUserRole
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, TbUserRole tbUserRole) {
        return super.exportXls(request, tbUserRole, TbUserRole.class, "角色表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, TbUserRole.class);
    }

}
